@@ -9,6 +9,7 @@ from .loxinfoonlyanalog import LoxInfoOnlyAnalog
 from .loxinfoonlydigital import LoxInfoOnlyDigital
 from .loxclimatecontroller import LoxClimateController
 from .loxjalousie import LoxJalousie
+from .loxmeter import LoxMeter
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -26,6 +27,7 @@ class ConfigData:
         self.covers = {}
         self.roomcontrollers = {}
         self.climatecontrollers = {}
+        self.meters = {}
 
         try:
             for k,v in self.data["controls"].items():
@@ -98,6 +100,27 @@ class ConfigData:
                         for stk,stv in sv["states"].items():
                             _LOGGER.debug("    state: {0} = {1}".format(stv, stk))
                             self.fieldmap[stv] = {"device": self.devices[sk], "stateName": stk}
+
+                if v["type"] == 'Meter':
+                    _LOGGER.debug("  Meter - {0}".format(k))
+                    self.meters[k] = LoxMeter(k, v["name"], v["type"], roomName, catName, v["details"])
+
+                    for tk,tv in v["states"].items():
+                        _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
+                        self.fieldmap[tv] = {"device": self.meters[k], "stateName": tk}
+#PresenceDetector
+#IRCV2Daytimer
+#TimedSwitch
+#Switch
+#Daytimer
+#Tracker
+#Window
+#AlarmClock
+
+
+
+
+
         except Exception as ex:
             _LOGGER.error(ex)
             
