@@ -72,13 +72,13 @@ class MessageBody:
 
                 if uuid in config_data.fieldmap:
                     try:
-                        _LOGGER.debug("UUID in fieldmap List {0}".format(uuid))
+                        #_LOGGER.debug("UUID in fieldmap List {0}".format(uuid))
                         mapentry = config_data.fieldmap[uuid]
 
                         device = mapentry["device"]
                         stateName = mapentry["stateName"]
 
-                        _LOGGER.debug("SettingValueState {0} {1} device_type: {2} state_name: {3}".format(device.id, device.name, device.device_type, mapentry["stateName"]))
+                        #_LOGGER.debug("SettingValueState {0} {1} device_type: {2} state_name: {3}".format(device.id, device.name, device.device_type, mapentry["stateName"]))
 
                         device.set_value(stateName, dval)
 
@@ -187,7 +187,7 @@ class MessageBody:
                         stateName = mapentry["stateName"]
 
                         if device.device_type == "ClimateController":
-                            _LOGGER.debug("ClimateController {0} {1} device_type: {2} state_name: {3} text: {4}".format(device.id, device.name, device.device_type, mapentry["stateName"], text))
+                            #_LOGGER.debug("ClimateController {0} {1} device_type: {2} state_name: {3} text: {4}".format(device.id, device.name, device.device_type, mapentry["stateName"], text))
 
                             if stateName == "controls":
                                 controls = json.loads(text)
@@ -195,7 +195,7 @@ class MessageBody:
                                     con_uuid = con['uuid']
                                     con_demand = con['demand']
 
-                                    _LOGGER.debug("  climate control - uuid: {0} demand: {1}".format(con_uuid, con_demand))
+                                    #_LOGGER.debug("  climate control - uuid: {0} demand: {1}".format(con_uuid, con_demand))
 
                                     for rck,rcv in config_data.roomcontrollers.items():
                                         #_LOGGER.debug("     available controller: {0}".format(rck))
@@ -205,7 +205,7 @@ class MessageBody:
 
 
                         else:
-                            _LOGGER.debug("SettingTextState {0} {1} device_type: {2} state_name: {3}".format(device.id, device.name, device.device_type, mapentry["stateName"]))
+                            #_LOGGER.debug("SettingTextState {0} {1} device_type: {2} state_name: {3}".format(device.id, device.name, device.device_type, mapentry["stateName"]))
 
                             device.set_value(stateName, text)
 
